@@ -5,20 +5,39 @@ def add(a,b):
     return a+b
 
 # 编码 70M1秒完成
-def encode(filename):
+def encode_p1(filename):
     with open(filename , 'rb') as f:
         text = f.read()
     ttt =  base64.b64encode(text)
     with open(filename+'.b64.txt','wb' ) as f:
         f.write(ttt)
 
-def decode(filename):
+def decode_p1(filename,piece=1):
     with open(filename , 'r') as f:
         text = f.read()
     de = base64.b64decode(text)
     # print(de)
     with open(filename+'.decode','wb' ) as f:
         f.write(de)
+        
+# 编码 70M1秒完成
+def encode(filename, piece=1):
+    with open(filename , 'rb') as f:
+        text = f.read()
+    ttt =  base64.b64encode(text)
+    index = int (len(ttt) / piece)
+    for i in  range(piece):
+        with open(filename+ '_' + str(i) +'.b64.txt','wb' ) as f:
+            f.write(ttt[index * i : index*(1+i)])
+
+def decode(filename,piece=1):
+    sss = ''
+    for i in  range(piece):
+        with open(filename + '_' + str(i) +'.b64.txt', 'r') as f:
+            sss += f.read()     
+    de = base64.b64decode(sss)
+    with open(filename+'.decode','wb' ) as f:
+        f.write(de)
 
 
  
@@ -40,5 +59,5 @@ def md5(file_name):
 
 
 if __name__ == '__main__':
-    a = md5(r'C:\Users\Administrator\Desktop\新建文件夹\dist\utils4file-1.0.4.tar.gz')
+    a = decode(r'C:\Users\Administrator\Desktop\ernie.bz2', 3)
     print(a)
\ No newline at end of file
